pub struct EventSender<'a> { /* private fields */ }Expand description
each select coroutine would use this struct to communicate with
the cqueue. the struct is created in add for each select coroutine
Implementations